@@ -201,15 +201,13 @@ Delete_Event( gchar *message )
 			  quit_dialog, "quit_label")),
 		  _("The frequency loop is running\n"\
 			"Really end operation?") );
-	else
-	  gtk_label_set_text( GTK_LABEL(lookup_widget(
-			  quit_dialog, "quit_label")),
-		  _("The frequency loop is running\n"\
-			"Really close this window?") );
+	else gtk_label_set_text( GTK_LABEL(lookup_widget(
+			quit_dialog, "quit_label")),
+		_("The frequency loop is running\n"\
+		  "Really close this window?") );
   }
-  else
-	gtk_label_set_text( GTK_LABEL(lookup_widget(
-			quit_dialog, "quit_label")), message );
+  else gtk_label_set_text( GTK_LABEL(lookup_widget(
+		  quit_dialog, "quit_label")), message );
 
 } /* Delete_Event() */
 
@@ -291,24 +289,19 @@ Open_Editor( GtkTreeView *view )
   /* Some "cards" have common editors */
   if( strcmp(card, "GC") == 0 )
 	Strlcpy( card, "GW", s );
-  else
-	if( strcmp(card, "SC") == 0 )
-	  Strlcpy( card, "SP", s );
-	else
-	  if( strcmp(card, "SM") == 0 )
-		Strlcpy( card, "SP", s );
-	  else
-		if( strcmp(card, "NH") == 0 )
-		  Strlcpy( card, "NE", s );
-		else
-		  if( strcmp(card, "GE") == 0 )
-		  {
-			Gend_Editor( EDITOR_EDIT );
-			return( TRUE );
-		  }
-		  else /* EN Not editable */
-			if( strcmp(card, "EN") == 0 )
-			  return( TRUE );
+  else if( strcmp(card, "SC") == 0 )
+	Strlcpy( card, "SP", s );
+  else if( strcmp(card, "SM") == 0 )
+	Strlcpy( card, "SP", s );
+  else if( strcmp(card, "NH") == 0 )
+	Strlcpy( card, "NE", s );
+  else if( strcmp(card, "GE") == 0 )
+  {
+	Gend_Editor( EDITOR_EDIT );
+	return( TRUE );
+  } /* EN Not editable */
+  else if( strcmp(card, "EN") == 0 )
+	return( TRUE );
 
   /* Send a "clicked" signal to the appropriate editor button */
   card[0] = (gchar)tolower((int)card[0]);
