@@ -94,8 +94,7 @@ on_new_activate     	              (GtkMenuItem     *menuitem,
 	infile[0] = '\0';
 	Open_Nec2_Editor( NEC2_EDITOR_NEW );
   }
-  else
-	Nec2_Input_File_Treeview( NEC2_EDITOR_NEW );	
+  else Nec2_Input_File_Treeview( NEC2_EDITOR_NEW );
 }
 
 
@@ -137,11 +136,10 @@ on_main_save_activate        (GtkMenuItem     *menuitem,
    * name. The count of each image type saved is incremented */
   if( isFlagSet(DRAW_CURRENTS) )
 	snprintf( saveas, 95, "%s-%s_%03d.%s", infile, "current", ++ccr, "png" );
+  else if( isFlagSet(DRAW_CHARGES) )
+	snprintf( saveas, 95, "%s-%s_%03d.%s", infile, "charge", ++cch, "png" );
   else
-	if( isFlagSet(DRAW_CHARGES) )
-	  snprintf( saveas, 95, "%s-%s_%03d.%s", infile, "charge", ++cch, "png" );
-	else
-	  snprintf( saveas, 95, "%s-%s_%03d.%s", infile, "geometry", ++cgm, "png" );
+	snprintf( saveas, 95, "%s-%s_%03d.%s", infile, "geometry", ++cgm, "png" );
   saveas[95] = '\0';
 
   saveas_pixmap = structure_pixmap;
@@ -252,12 +250,11 @@ on_main_freqplots_activate             (GtkMenuItem     *menuitem,
 	  Set_Window_Labels();
 	  calc_data.ngraph = 0;
 	} /* if( Main_Freqplots_Activate() */
-	else
-	  gtk_check_menu_item_set_active(
-		  GTK_CHECK_MENU_ITEM(menuitem), FALSE );
+	else gtk_check_menu_item_set_active(
+		GTK_CHECK_MENU_ITEM(menuitem), FALSE );
   }
   else if( isFlagSet(PLOT_ENABLED) )
-	  gtk_widget_destroy( freqplots_window );
+	gtk_widget_destroy( freqplots_window );
 }
 
 
@@ -874,11 +871,9 @@ on_rdpattern_save_activate             (GtkMenuItem     *menuitem,
    * file name from input name */
   if( isFlagSet(DRAW_GAIN) )
 	snprintf( saveas, 95, "%s-%s_%03d.%s", infile, "gain", ++cgn, "png" );
-  else
-	if( isFlagSet(DRAW_EHFIELD) )
-	  snprintf( saveas, 95, "%s-%s_%03d.%s", infile, "fields", ++ceh, "png" );
-	else
-	  return;
+  else if( isFlagSet(DRAW_EHFIELD) )
+	snprintf( saveas, 95, "%s-%s_%03d.%s", infile, "fields", ++ceh, "png" );
+  else return;
   saveas[95] = '\0';
 
   saveas_pixmap = rdpattern_pixmap;
@@ -1374,8 +1369,7 @@ on_near_peak_value_activate            (GtkMenuItem     *menuitem,
 	  Draw_Radiation( rdpattern_drawingarea );
 	}
   }
-  else
-	SetFlag( NEAREH_SNAPSHOT );
+  else SetFlag( NEAREH_SNAPSHOT );
 
   /* Reset child near field flags */
   Pass_EH_Flags();
@@ -1398,8 +1392,7 @@ on_near_snapshot_activate              (GtkMenuItem     *menuitem,
 	  Draw_Radiation( rdpattern_drawingarea );
 	}
   }
-  else
-	ClearFlag( NEAREH_SNAPSHOT );
+  else ClearFlag( NEAREH_SNAPSHOT );
 
   /* Reset child near field flags */
   Pass_EH_Flags();
@@ -1636,9 +1629,8 @@ on_nec2_row_add_clicked                (GtkButton       *button,
 	model = gtk_tree_view_get_model( selected_treeview );
 	gtk_list_store_insert( GTK_LIST_STORE(model), &iter, 0 );
   }
-  else
-	gtk_list_store_insert_after(
-		GTK_LIST_STORE(model), &iter, &sibling);
+  else gtk_list_store_insert_after(
+	  GTK_LIST_STORE(model), &iter, &sibling);
 
   /* Prime columns of new row */
   ncols = gtk_tree_model_get_n_columns( model );
@@ -1739,7 +1731,8 @@ on_nec2_revert_clicked                 (GtkButton       *button,
   Nec2_Input_File_Treeview( NEC2_EDITOR_REVERT );
 }
 
-
+void on_error_stopbutton_clicked(
+	GtkButton *button, gpointer user_data) __attribute__ ((noreturn));
 void
 on_error_stopbutton_clicked            (GtkButton       *button,
                                         gpointer         user_data)
