@@ -344,8 +344,10 @@ Draw_Radiation_Pattern( void )
   } /* for( nth = 0; nth < fpat.nth; nth++ ) */
 
   /* Show gain in direction of viewer */
-  Show_Viewer_Gain( rdpattern_window,
-	  "rdpattern_viewer_gain", rdpattern_proj_params );
+  Show_Viewer_Gain(
+	  rdpattern_window,
+	  "rdpattern_viewer_gain",
+	  rdpattern_proj_params );
 
   cairo_destroy( cr );
 } /* Draw_Radiation_Pattern() */
@@ -382,7 +384,7 @@ Draw_Near_Field( void )
   GdkSegment segm;
 
   /* For coloring field lines */
-  double red = 0.0, grn = 0.0, blu = 0.0;
+  double xred = 0.0, xgrn = 0.0, xblu = 0.0;
 
   /* Abort if drawing a near field pattern is not possible */
   if( isFlagClear(ENABLE_NEAREH) || !near_field.valid )
@@ -449,7 +451,7 @@ Draw_Near_Field( void )
 	if( isFlagSet(DRAW_EFIELD) && (fpat.nfeh & NEAR_EFIELD) )
 	{
 	  /* Set gc attributes for segment */
-	  Value_to_Color( &red, &grn, &blu,
+	  Value_to_Color( &xred, &xgrn, &xblu,
 		  near_field.er[idx], near_field.max_er );
 
 	  /* Scale factor for each field point, to make
@@ -471,7 +473,7 @@ Draw_Near_Field( void )
 		  fx, fy, fz );
 
 	  /* Draw segment */
-	  cairo_set_source_rgb( cr, red, grn, blu );
+	  cairo_set_source_rgb( cr, xred, xgrn, xblu );
 	  Cairo_Draw_Line( cr, segm.x1, segm.y1, segm.x2, segm.y2 );
 
 	} /* if( isFlagSet(DRAW_EFIELD) && (fpat.nfeh & NEAR_EFIELD) ) */
@@ -480,7 +482,7 @@ Draw_Near_Field( void )
 	if( isFlagSet(DRAW_HFIELD) && (fpat.nfeh & NEAR_HFIELD) )
 	{
 	  /* Set gc attributes for segment */
-	  Value_to_Color( &red, &grn, &blu,
+	  Value_to_Color( &xred, &xgrn, &xblu,
 		  near_field.hr[idx], near_field.max_hr );
 
 	  /* Scale factor for each field point, to make
@@ -502,7 +504,7 @@ Draw_Near_Field( void )
 		  fx, fy, fz );
 
 	  /* Draw segment */
-	  cairo_set_source_rgb( cr, red, grn, blu );
+	  cairo_set_source_rgb( cr, xred, xgrn, xblu );
 	  Cairo_Draw_Line( cr, segm.x1, segm.y1, segm.x2, segm.y2 );
 
 	} /* if( isFlagSet(DRAW_HFIELD) && (fpat.nfeh & NEAR_HFIELD) ) */
@@ -547,7 +549,7 @@ Draw_Near_Field( void )
 	  } /* for( ipv = 0; ipv < npts; ipv++ ) */
 
 	  /* Set gc attributes for segment */
-	  Value_to_Color( &red, &grn, &blu, pov_r[idx], pov_max );
+	  Value_to_Color( &xred, &xgrn, &xblu, pov_r[idx], pov_max );
 
 	  /* Scale factor for each field point, to make
 	   * near field direction lines equal-sized */
@@ -569,7 +571,7 @@ Draw_Near_Field( void )
 		  near_field.pz[idx], fx, fy, fz );
 
 	  /* Draw segment */
-	  cairo_set_source_rgb( cr, red, grn, blu );
+	  cairo_set_source_rgb( cr, xred, xgrn, xblu );
 	  Cairo_Draw_Line( cr, segm.x1, segm.y1, segm.x2, segm.y2 );
 
 	} /* if( isFlagSet(DRAW_POYNTING) ) */
@@ -585,12 +587,10 @@ Draw_Near_Field( void )
   /* Show max field strength on color code bar */
   if( isFlagSet(DRAW_EFIELD) )
 	max = near_field.max_er;
-  else
-	if( isFlagSet(DRAW_HFIELD) )
-	  max = near_field.max_hr;
-	else
-	  if( isFlagSet(DRAW_POYNTING) )
-		max = pov_max;
+  else if( isFlagSet(DRAW_HFIELD) )
+	max = near_field.max_hr;
+  else if( isFlagSet(DRAW_POYNTING) )
+	max = pov_max;
 
   snprintf( txt, 9, "%8.2E", max );
   gtk_label_set_text(
@@ -683,7 +683,7 @@ static int gain_style = GS_LINP;
 Scale_Gain( double gain, int fstep, int idx )
 {
   /* Scaled rad pattern gain and pol factor */
-  double rad = 0.0, polf;
+  double scaled_rad = 0.0, polf;
 
   polf = Polarization_Factor( calc_data.pol_type, fstep, idx );
   if ( polf< 1e-200 ) return( 0.0 );
@@ -693,27 +693,27 @@ Scale_Gain( double gain, int fstep, int idx )
   switch( gain_style )
   {
 	case GS_LINP:
-	  rad = pow(10.0, (gain/10.0));
+	  scaled_rad = pow(10.0, (gain/10.0));
 	  break;
 
 	case GS_LINV:
-	  rad = pow(10.0, (gain/20.0));
+	  scaled_rad = pow(10.0, (gain/20.0));
 	  break;
 
 	case GS_ARRL:
-	  rad = exp( 0.058267 * gain );
+	  scaled_rad = exp( 0.058267 * gain );
 	  break;
 
 	case GS_LOG:
-	  rad = gain;
-	  if( rad < -40 )
-		rad = 0.0;
+	  scaled_rad = gain;
+	  if( scaled_rad < -40 )
+		scaled_rad = 0.0;
 	  else
-		rad = rad /40.0 + 1.0;
+		scaled_rad = scaled_rad /40.0 + 1.0;
 
   } /* switch( gain_style ) */
 
-  return( rad );
+  return( scaled_rad );
 
 } /* Scale_Gain() */
 
@@ -722,12 +722,12 @@ Scale_Gain( double gain, int fstep, int idx )
 /* Polarization_Factor()
  *
  * Calculates polarization factor from axial
- * ratio and tilt of polarization ellepse
+ * ratio and tilt of polarization ellipse
  */
   double
 Polarization_Factor( int pol_type, int fstep, int idx )
 {
-  double axrt2, tlt, polf = 1.0;
+  double axrt, axrt2, tilt2, polf = 1.0;
 
   switch( pol_type )
   {
@@ -736,33 +736,31 @@ Polarization_Factor( int pol_type, int fstep, int idx )
 	  break;
 
 	case POL_HORIZ:
-	  axrt2 = rad_pattern[fstep].axrt[idx] *
-		rad_pattern[fstep].axrt[idx];
-	  tlt = sin( rad_pattern[fstep].tilt[idx] );
-	  polf = (axrt2 + (1.0 - axrt2) * tlt * tlt) /
-		(1.0 + axrt2);
+	  axrt2  = rad_pattern[fstep].axrt[idx];
+	  axrt2 *= axrt2;
+	  tilt2  = sin( rad_pattern[fstep].tilt[idx] );
+	  tilt2 *= tilt2;
+	  polf = (axrt2 + (1.0 - axrt2) * tilt2) / (1.0 + axrt2);
 	  break;
 
 	case POL_VERT:
-	  axrt2 = rad_pattern[fstep].axrt[idx] *
-		rad_pattern[fstep].axrt[idx];
-	  tlt = cos( rad_pattern[fstep].tilt[idx] );
-	  polf = (axrt2 + (1.0 - axrt2) * tlt * tlt) /
-		(1.0 + axrt2);
+	  axrt2  = rad_pattern[fstep].axrt[idx];
+	  axrt2 *= axrt2;
+	  tilt2  = cos( rad_pattern[fstep].tilt[idx] );
+	  tilt2 *= tilt2;
+	  polf = (axrt2 + (1.0 - axrt2) * tilt2) / (1.0 + axrt2);
 	  break;
 
 	case POL_LHCP:
-	  axrt2 = rad_pattern[fstep].axrt[idx] *
-		rad_pattern[fstep].axrt[idx];
-	  polf = (1.0 + 2.0 * rad_pattern[fstep].axrt[idx] +
-		  axrt2) / 2.0 / (1.0 + axrt2);
+	  axrt  = rad_pattern[fstep].axrt[idx];
+	  axrt2 = axrt * axrt;
+	  polf  = (1.0 + 2.0 * axrt + axrt2) / 2.0 / (1.0 + axrt2);
 	  break;
 
 	case POL_RHCP:
-	  axrt2 = rad_pattern[fstep].axrt[idx] *
-		rad_pattern[fstep].axrt[idx];
-	  polf = (1.0 - 2.0 * rad_pattern[fstep].axrt[idx] +
-		  axrt2) / 2.0 / (1.0 + axrt2);
+	  axrt  = rad_pattern[fstep].axrt[idx];
+	  axrt2 = axrt * axrt;
+	  polf  = (1.0 - 2.0 * axrt + axrt2) / 2.0 / (1.0 + axrt2);
   }
 
   return( polf );
@@ -880,13 +878,14 @@ Redo_Radiation_Pattern( gpointer udata )
   double
 Viewer_Gain( projection_parameters_t proj_parameters, int fstep )
 {
-  double phi, gain=-999;
+  double phi, gain;
   int nth, nph, idx;
 
 
   /* Calculate theta step from proj params */
   phi = proj_parameters.Wr;
-  if( fpat.dth == 0.0 )	nth = 0;
+  if( fpat.dth == 0.0 )
+	nth = 0;
   else
   {
 	double theta = fabs( 90.0 - proj_parameters.Wi );
@@ -896,23 +895,27 @@ Viewer_Gain( projection_parameters_t proj_parameters, int fstep )
 	  phi  -= 180.0;
 	}
 	if( (gnd.ksymp == 2) && (theta > 90.01) && (gnd.ifar != 1) )
-	  return( -999.0 );
+	  return( -999.99 );
 	nth = (int)( theta/fpat.dth + 0.5 );
-	if( (nth >= fpat.nth) || (nth < 0) ) nth = fpat.nth-1;
+	if( (nth >= fpat.nth) || (nth < 0) )
+	  nth = fpat.nth-1;
   }
 
   /* Calculate phi step from proj params */
-  if( fpat.dph == 0.0 )	nph = 0;
+  if( fpat.dph == 0.0 )
+	nph = 0;
   else
   {
 	while( phi < 0.0 ) phi += 360.0;
 	nph = (int)( phi/fpat.dph + 0.5 );
-	if( (nph >= fpat.nph) || (nph < 0) ) nph = fpat.nph-1;
+	if( (nph >= fpat.nph) || (nph < 0) )
+	  nph = fpat.nph-1;
   }
 
   idx = nth + nph*fpat.nth;
-  gain = rad_pattern[fstep].gtot[idx] +	10.0 *
-	log10( Polarization_Factor(calc_data.pol_type, fstep, idx) );
+  gain = rad_pattern[fstep].gtot[idx] +
+		10.0 * log10( Polarization_Factor(calc_data.pol_type, fstep, idx) );
+  if( gain < -999.99 ) gain = -999.99;
 
   return( gain );
 
