@@ -35,7 +35,8 @@
 Draw_Structure( GtkWidget *drawingarea )
 {
   /* Block motion events */
-  g_signal_handler_block( (gpointer)drawingarea, structure_motion_handler );
+  g_signal_handler_block
+	( (gpointer)drawingarea, structure_motion_handler );
 
   /* Abort if xnec2c may be quit by user */
   if( isFlagSet(MAIN_QUIT) )
@@ -622,8 +623,7 @@ Draw_Surface_Patches( GdkSegment *segm, gint npatch )
 	if( isFlagSet(OVERLAY_STRUCT) &&
 		(structure_proj_params.type == RDPATTERN_DRAWINGAREA) )
 	  cairo_set_source_rgb( cr, WHITE );
-	else
-	  cairo_set_source_rgb( cr, BLUE );
+	else cairo_set_source_rgb( cr, BLUE );
 
 	/* Draw patch segments */
 	int nsg = 2 * npatch;
@@ -686,7 +686,8 @@ New_Structure_Projection_Angle(void)
   structure_proj_params.cos_wi = cos(structure_proj_params.Wi/(double)TD);
 
   /* Trigger a redraw of structure drawingarea */
-  Draw_Structure( structure_drawingarea );
+  if( isFlagClear(INPUT_PENDING) )
+	Draw_Structure( structure_drawingarea );
 
   /* Trigger a redraw of plots drawingarea */
   if( isFlagSet(PLOT_ENABLED) && isFlagSet(PLOT_GVIEWER) )
