@@ -324,8 +324,7 @@ void efld( double xi, double yi,
 	rh= r- zp* zp;
 	if( rh <= 1.0e-10)
 	  dmin=0.0;
-	else
-	  dmin= sqrt( rh/( rh+ ai* ai));
+	else dmin= sqrt( rh/( rh+ ai* ai));
 
 	if( dmin <= .95)
 	{
@@ -1265,37 +1264,36 @@ void nefld( double xob, double yob,
 			  dataj.ind1=0;
 		  }
 		} /* if( ipr < 0 ) */
+		else if( ipr == 0 )
+		  dataj.ind1=1;
 		else
-		  if( ipr == 0 )
-			dataj.ind1=1;
-		  else
-		  {
-			iprx = ipr-1;
+		{
+		  iprx = ipr-1;
 
-			if( ipr != ix )
-			{
-			  if( data.icon2[iprx] != ix )
-				dataj.ind1=2;
-			  else
-			  {
-				xi= fabs( dataj.cabj* data.cab[iprx]+ dataj.sabj*
-					data.sab[iprx]+ dataj.salpj* data.salp[iprx]);
-				if( (xi < 0.999999) ||
-					(fabs(data.bi[iprx]/dataj.b-1.0) > 1.0e-6) )
-				  dataj.ind1=2;
-				else
-				  dataj.ind1=0;
-			  }
-			} /* if( ipr != ix ) */
+		  if( ipr != ix )
+		  {
+			if( data.icon2[iprx] != ix )
+			  dataj.ind1=2;
 			else
 			{
-			  if( dataj.cabj* dataj.cabj +
-				  dataj.sabj* dataj.sabj > 1.0e-8)
+			  xi= fabs( dataj.cabj* data.cab[iprx]+ dataj.sabj*
+				  data.sab[iprx]+ dataj.salpj* data.salp[iprx]);
+			  if( (xi < 0.999999) ||
+				  (fabs(data.bi[iprx]/dataj.b-1.0) > 1.0e-6) )
 				dataj.ind1=2;
 			  else
 				dataj.ind1=0;
 			}
-		  } /* else */
+		  } /* if( ipr != ix ) */
+		  else
+		  {
+			if( dataj.cabj* dataj.cabj +
+				dataj.sabj* dataj.sabj > 1.0e-8)
+			  dataj.ind1=2;
+			else
+			  dataj.ind1=0;
+		  }
+		} /* else */
 
 		ipr= data.icon2[i];
 
@@ -1318,38 +1316,37 @@ void nefld( double xob, double yob,
 			  dataj.ind1=0;
 		  }
 		} /* if( ipr < 0 ) */
+		else if( ipr == 0 )
+		  dataj.ind2=1;
 		else
-		  if( ipr == 0 )
-			dataj.ind2=1;
-		  else
-		  {
-			iprx = ipr-1;
+		{
+		  iprx = ipr-1;
 
-			if( ipr != ix )
-			{
-			  if( data.icon1[iprx] != ix )
-				dataj.ind2=2;
-			  else
-			  {
-				xi= fabs( dataj.cabj* data.cab[iprx]+ dataj.sabj*
-					data.sab[iprx]+ dataj.salpj* data.salp[iprx]);
-				if( (xi < 0.999999) ||
-					(fabs(data.bi[iprx]/dataj.b-1.0) > 1.0e-6) )
-				  dataj.ind2=2;
-				else
-				  dataj.ind2=0;
-			  }
-			} /* if( ipr != (i+1) ) */
+		  if( ipr != ix )
+		  {
+			if( data.icon1[iprx] != ix )
+			  dataj.ind2=2;
 			else
 			{
-			  if( dataj.cabj* dataj.cabj +
-				  dataj.sabj* dataj.sabj > 1.0e-8)
-				dataj.ind1=2;
+			  xi= fabs( dataj.cabj* data.cab[iprx]+ dataj.sabj*
+				  data.sab[iprx]+ dataj.salpj* data.salp[iprx]);
+			  if( (xi < 0.999999) ||
+				  (fabs(data.bi[iprx]/dataj.b-1.0) > 1.0e-6) )
+				dataj.ind2=2;
 			  else
-				dataj.ind1=0;
+				dataj.ind2=0;
 			}
+		  } /* if( ipr != (i+1) ) */
+		  else
+		  {
+			if( dataj.cabj* dataj.cabj +
+				dataj.sabj* dataj.sabj > 1.0e-8)
+			  dataj.ind1=2;
+			else
+			  dataj.ind1=0;
+		  }
 
-		  } /* else */
+		} /* else */
 
 	  } /* if( dataj.iexk != 0) */
 
