@@ -31,6 +31,7 @@
  * Destination of child processes, handles data
  * transfers between parent and children via pipes
  */
+void Child_Process( int num_child ) __attribute__ ((noreturn));
   void
 Child_Process( int num_child )
 {
@@ -328,8 +329,7 @@ Pass_Freq_Data( void )
 	  /* newer & valid flags */
 	  2 * sizeof(char);
   }
-  else
-	/* Notify parent not to read near field data */
+  else /* Notify parent not to read near field data */
 	Write_Pipe( num_child_procs, "noeh", 4, TRUE );
 
   /* Allocate data buffers */
