@@ -435,19 +435,18 @@ conect( int ignd )
 		while( ix != 0 );
 
 		if( jump && (iend == 1) ) break;
-		else
-		  if( jump )
-		  {
-			iend=1;
-			jend=1;
-			ix= data.icon2[j];
-			ic=1;
-			segj.jco[0]= jx;
-			xa= data.x2[j];
-			ya= data.y2[j];
-			za= data.z2[j];
-			continue;
-		  }
+		else if( jump )
+		{
+		  iend=1;
+		  jend=1;
+		  ix= data.icon2[j];
+		  ic=1;
+		  segj.jco[0]= jx;
+		  xa= data.x2[j];
+		  ya= data.y2[j];
+		  za= data.z2[j];
+		  continue;
+		}
 
 		sep= (double)ic;
 		xa= xa/ sep;
