@@ -631,12 +631,11 @@ void cmww( int j, int i1, int i2, complex double *cmx,
 		  } /* if( data.icon2[iprx] != jx ) */
 
 		} /* if( ipr != jx ) */
+		else if( (dataj.cabj* dataj.cabj +
+			  dataj.sabj* dataj.sabj) > 1.0e-8)
+		  dataj.ind1=2;
 		else
-		  if( (dataj.cabj* dataj.cabj +
-				dataj.sabj* dataj.sabj) > 1.0e-8)
-			dataj.ind1=2;
-		  else
-			dataj.ind1=0;
+		  dataj.ind1=0;
 
 	  } /* if( ipr == 0 ) */
 
@@ -687,12 +686,11 @@ void cmww( int j, int i1, int i2, complex double *cmx,
 		  } /* if( data.icon2[iprx] != jx ) */
 
 		} /* if( ipr != jx ) */
+		else if( (dataj.cabj* dataj.cabj +
+			  dataj.sabj* dataj.sabj) > 1.0e-8)
+		  dataj.ind2=2;
 		else
-		  if( (dataj.cabj* dataj.cabj +
-				dataj.sabj* dataj.sabj) > 1.0e-8)
-			dataj.ind2=2;
-		  else
-			dataj.ind2=0;
+		  dataj.ind2=0;
 
 	  } /* if( ipr == 0 ) */
 
@@ -1254,8 +1252,7 @@ fblock( int nrow, int ncol, int imax, int ipsym )
 	  matpar.icase=1;
 	  return;
 	}
-	else
-	  matpar.icase=2;
+	else matpar.icase=2;
 
   } /* if( nrow*ncol <= imax) */
 
