@@ -69,7 +69,6 @@ Plot_Frequency_Data( void )
 
   static double
 	*gmax     = NULL, /* Max gain buffer */
-	*netgmax  = NULL, /* Net Max gain buffer */
 	*vgain    = NULL, /* Viewer direction gain buffer */
 	*netgain  = NULL, /* Viewer direction net gain buffer */
 	*gdir_tht = NULL, /* Direction in theta of gain */
@@ -316,7 +315,7 @@ Plot_Frequency_Data( void )
   /* Plot VSWR vs freq */
   if( isFlagSet(PLOT_VSWR) )
   {
-	double vswr[calc_data.nfrq], gamma;
+	double *vswr = NULL, gamma;
 	double zrpro2, zrmro2, zimag2;
 
 	/* Plotting frame titles */
@@ -324,6 +323,17 @@ Plot_Frequency_Data( void )
 	titles[1] = _("VSWR vs Frequency");
 
 	/* Calculate VSWR */
+	mem_alloc( (void *)&vswr,
+		(size_t)calc_data.nfrq * sizeof(double),
+		"in Plot_Frequency_Data()" );
+	if( vswr == NULL )
+	{
+	  fprintf( stderr, "xnec2c: Plot_Frequency_Data():"
+		  "memory allocation for vswr failed\n" );
+	  stop( _("Plot_Frequency_Data():"
+			"Memory allocation for vswr failed"), ERR_OK );
+	  return;
+	}
 	for(idx = 0; idx < fstep; idx++ )
 	{
 	  zrpro2 = impedance_data.zreal[idx] + calc_data.zo;
@@ -336,39 +346,12 @@ Plot_Frequency_Data( void )
 	  if( vswr[idx] > 10.0 ) vswr[idx] = 10.0;
 	}
 
-	/* Plot net gain if selected */
-	if( isFlagSet(PLOT_NETGAIN) )
-	{
-	  int mgidx, pol;
-	  double max_gain;
-
-	  size_t mreq = (size_t)fstep * sizeof(double);
-	  mem_realloc( (void *)&netgmax, mreq, "in plot_freqdata.c" );
-
-	  Zo = calc_data.zo;
-	  for(idx = 0; idx < fstep; idx++ )
-	  {
-		Zr = impedance_data.zreal[idx];
-		Zi = impedance_data.zimag[idx];
-		pol = calc_data.pol_type;
-		mgidx = rad_pattern[idx].max_gain_idx[pol];
-		/* Max gain for given polarization type */
-		max_gain = rad_pattern[idx].gtot[mgidx] +
-		  10.0 * log10( Polarization_Factor(pol, idx, mgidx) );
-		netgmax[idx] = max_gain + 10*log10(4*Zr*Zo/(pow(Zr+Zo,2)+pow(Zi,2)));
-	  }
-
-	  titles[2] = _("Net Gain dbi");
-	  Plot_Graph2( vswr, netgmax, save.freq, fstep,
+	titles[2] = "        ";
+	if( fstep > 1 )
+	  Plot_Graph( vswr, save.freq, fstep,
 		  titles, calc_data.ngraph, ++posn );
-	} /* if( isFlagSet(PLOT_NETGAIN) ) */
-	else
-	{
-	  titles[2] = "        ";
-	  if( fstep > 1 )
-		Plot_Graph( vswr, save.freq, fstep,
-			titles, calc_data.ngraph, ++posn );
-	}
+
+	free_ptr( (void *)&vswr );
   } /* if( isFlagSet(PLOT_VSWR) ) */
 
   /* Plot z-real and z-imag */
@@ -624,8 +607,7 @@ Plot_Vertical_Scale(
 	double mo = log10( fabs(max) );
 	max_order = (int)mo;
   }
-  else
-	max_order = 0;
+  else max_order = 0;
 
   /* Use highest order for format */
   order = ( max_order > min_order ? max_order : min_order );
@@ -645,7 +627,7 @@ Plot_Vertical_Scale(
   for( idx = 0; idx < nval; idx++ )
   {
 	yps = y + (idx * height) / (nval-1);
-	snprintf( value, 16, format, max );
+	snprintf( value, 16, (const char *)format, max );
 	value[15] = '\0';
 	pango_layout_set_text( layout, value, -1 );
 	cairo_move_to( cr, x, yps );
@@ -707,7 +689,7 @@ Plot_Horizontal_Scale(
   for( idx = 0; idx < nval; idx++ )
   {
 	xps = x + (idx * width) / (nval-1);
-	snprintf( value, 16, format, min );
+	snprintf( value, 16, (const char *)format, min );
 	value[15] = '\0';
 	pango_layout_set_text( layout, value, -1 );
 	cairo_move_to( cr, xps, y );
@@ -736,7 +718,7 @@ Draw_Graph(
 {
   double ra, rb;
   int idx;
-  GdkPoint points[nval], polygn[4];
+  GdkPoint *points = NULL, polygn[4];
 
   /* Cairo context */
   cairo_t *cr = gdk_cairo_create( freqplots_pixmap );
@@ -747,6 +729,17 @@ Draw_Graph(
   rb = bmax - bmin;
 
   /* Calculate points to plot */
+  mem_alloc( (void *)&points,
+	  (size_t)calc_data.nfrq * sizeof(GdkPoint),
+	  "in Plot_Frequency_Data()" );
+  if( points == NULL )
+  {
+	fprintf( stderr, "xnec2c: Draw_Graph():"
+		"memory allocation for points failed\n" );
+	stop( _("Draw_Graph():"
+		  "Memory allocation for points failed"), ERR_OK );
+	return;
+  }
   for( idx = 0; idx < nval; idx++ )
   {
 	points[idx].x = rect->x + (int)( (double)rect->width  *
@@ -776,6 +769,7 @@ Draw_Graph(
   /* Draw the graph */
   Cairo_Draw_Lines( cr, points, nval );
 
+  free_ptr( (void *)&points );
   cairo_destroy( cr );
 } /* Draw_Graph() */
 
@@ -821,17 +815,16 @@ Fit_to_Scale( double *max, double *min, int *nval )
 	  *max =  1.0;
 	  *min = -1.0;
 	}
+	else if( *max > 0.0 )
+	{
+	  *max *= 1.5;
+	  *min /= 2.0;
+	}
 	else
-	  if( *max > 0.0 )
-	  {
-		*max *= 1.5;
-		*min /= 2.0;
-	  }
-	  else
-	  {
-		*max /= 2.0;
-		*min *= 1.5;
-	  }
+	{
+	  *max /= 2.0;
+	  *min *= 1.5;
+	}
   }
 
   /* Find subdivision's lower order of magnitude */
@@ -890,17 +883,16 @@ Fit_to_Scale2( double *max1, double *min1,
 	  *max1 =  1.0;
 	  *min1 = -1.0;
 	}
+	else if( *max1 > 0.0 )
+	{
+	  *max1 *= 1.5;
+	  *min1 /= 2.0;
+	}
 	else
-	  if( *max1 > 0.0 )
-	  {
-		*max1 *= 1.5;
-		*min1 /= 2.0;
-	  }
-	  else
-	  {
-		*max1 /= 2.0;
-		*min1 *= 1.5;
-	  }
+	{
+	  *max1 /= 2.0;
+	  *min1 *= 1.5;
+	}
   }
 
   if( *max2 == *min2 )
@@ -910,17 +902,16 @@ Fit_to_Scale2( double *max1, double *min1,
 	  *max2 =  1.0;
 	  *min2 = -1.0;
 	}
+	else if( *max2 > 0.0 )
+	{
+	  *max2 *= 1.5;
+	  *min2 /= 2.0;
+	}
 	else
-	  if( *max2 > 0.0 )
-	  {
-		*max2 *= 1.5;
-		*min2 /= 2.0;
-	  }
-	  else
-	  {
-		*max2 /= 2.0;
-		*min2 *= 1.5;
-	  }
+	{
+	  *max2 /= 2.0;
+	  *min2 *= 1.5;
+	}
   }
 
   /* For each scale */
