@@ -111,8 +111,7 @@ void somnec( double epr, double sig, double fmhz )
 	wlam=CVEL/fmhz;
 	ggrid.epscf=cmplx(epr,-sig*wlam*59.96);
   }
-  else
-	ggrid.epscf=cmplx(epr,sig);
+  else ggrid.epscf=cmplx(epr,sig);
 
   ck2=TP;
   ck2sq=ck2*ck2;
@@ -469,8 +468,7 @@ evlua( complex double *erv, complex double *ezv,
 	jump = TRUE;
 
   } /* if( (rmis >= 2.0*ck2) || (rho >= 1.0e-10) ) */
-  else
-	jump = FALSE;
+  else jump = FALSE;
 
   if( ! jump )
   {
@@ -539,8 +537,7 @@ fbar( complex double p, complex double *fbar )
 	minus=1;
 	z= -z;
   }
-  else
-	minus=0;
+  else minus=0;
 
   zs=0.5/( z* z);
   sum=CPLX_00;
@@ -662,8 +659,7 @@ gshank( complex double start, complex double dela,
 			a2=aa-q1[idx];
 			a1=q1[idx]-a2*a2/a1;
 		  }
-		  else
-			a1=q1[idx];
+		  else a1=q1[idx];
 
 		  a2=aa+as2-2.0*as1;
 		  if( (creal(a2) != 0.0) || (cimag(a2) != 0.0) )
@@ -1122,8 +1118,7 @@ void saoa( double t, complex double *ans)
 	}
 
   } /* if(xlr < tsmag) */
-  else
-	dgam=cgam2-cgam1;
+  else dgam=cgam2-cgam1;
 
   den2=cksm*dgam/(cgam2*(ck1sq*cgam2+ck2sq*cgam1));
   den1=1.0/(cgam1+cgam2)-cksm/cgam2;
